==> brillouin-zone-1.1.6.tar.gz: brillouin-zone-1.1.6/brillouin_zone/cmpl_vector.h <==
#ifndef CMPL_VEC_INCLUDED 
#define CMPL_VEC_INCLUDED 
#define BOOST_PYTHON_ENABLE_STDCALL
#include <boost/python.hpp>
#include <vector>
#include <complex>

#include <boost/python/stl_iterator.hpp>
#include <boost/python/suite/indexing/vector_indexing_suite.hpp>
#include </usr/local/Cellar/boost/1.62.0/include/boost/python/converter/builtin_converters.hpp>

/// @brief Type that allows for registration of conversions from
///        python iterable types.

struct iterable_converter
{
  /// @note Registers converter from a python iterable type to the
  ///       provided type.
  template <typename Container>
  iterable_converter&
  from_python()
  {
    boost::python::converter::registry::push_back(
       &iterable_converter::convertible,
       &iterable_converter::construct<Container>,
       boost::python::type_id<Container>());

    // Support chaining.
    return *this;  
  }

  /// @brief Check if PyObject is iterable.
  static void* convertible(PyObject* object)
  {
    return PyObject_GetIter(object) ? object : NULL;
  }

  /// @brief Convert iterable PyObject to C++ container type.
  //  
  /// Container Concept requirements:
  //  
  ///   * Container::value_type is CopyConstructable.
  ///   * Container can be constructed and populated with two iterators.
  ///     I.e. Container(begin, end)
  template <typename Container>
  static void construct(
      PyObject* object,
      boost::python::converter::rvalue_from_python_stage1_data* data)
  {
    namespace python = boost::python;

    python::handle<> handle(python::borrowed(object));

    typedef python::converter::rvalue_from_python_storage<Container> storage_type;

    void* storage = reinterpret_cast<storage_type*>(data)->storage.bytes;

    typedef python::stl_input_iterator<typename Container::value_type> iterator;

    // Allocate the C++ type into the converter's memory block, and assign
    // its handle to the converter's convertible variable.  The C++
    // container is populated by passing the begin and end iterators of
    // the python object to the container's constructor.
    new (storage) Container(
      iterator(python::object(handle)), // begin
      iterator());                      // end
    data->convertible = storage;
  }
};


#endif

==> brillouin-zone-1.1.7.tar.gz: brillouin-zone-1.1.7/brillouin_zone/cmpl_vector.h <==
#ifndef CMPL_VEC_INCLUDED 
#define CMPL_VEC_INCLUDED 
#define BOOST_PYTHON_ENABLE_STDCALL
#include <boost/python.hpp>
#include <vector>
#include <complex>

#include <boost/python/stl_iterator.hpp>
#include <boost/python/suite/indexing/vector_indexing_suite.hpp>
#include <boost/python/converter/builtin_converters.hpp>

/// @brief Type that allows for registration of conversions from
///        python iterable types.

struct iterable_converter
{
  /// @note Registers converter from a python iterable type to the
  ///       provided type.
  template <typename Container>
  iterable_converter&
  from_python()
  {
    boost::python::converter::registry::push_back(
       &iterable_converter::convertible,
       &iterable_converter::construct<Container>,
       boost::python::type_id<Container>());

    // Support chaining.
    return *this;  
  }

  /// @brief Check if PyObject is iterable.
  static void* convertible(PyObject* object)
  {
    return PyObject_GetIter(object) ? object : NULL;
  }

  /// @brief Convert iterable PyObject to C++ container type.
  //  
  /// Container Concept requirements:
  //  
  ///   * Container::value_type is CopyConstructable.
  ///   * Container can be constructed and populated with two iterators.
  ///     I.e. Container(begin, end)
  template <typename Container>
  static void construct(
      PyObject* object,
      boost::python::converter::rvalue_from_python_stage1_data* data)
  {
    namespace python = boost::python;

    python::handle<> handle(python::borrowed(object));

    typedef python::converter::rvalue_from_python_storage<Container> storage_type;

    void* storage = reinterpret_cast<storage_type*>(data)->storage.bytes;

    typedef python::stl_input_iterator<typename Container::value_type> iterator;

    // Allocate the C++ type into the converter's memory block, and assign
    // its handle to the converter's convertible variable.  The C++
    // container is populated by passing the begin and end iterators of
    // the python object to the container's constructor.
    new (storage) Container(
      iterator(python::object(handle)), // begin
      iterator());                      // end
    data->convertible = storage;
  }
};


#endif
